#ifndef _CONSERVED_PATH_H
#define _CONSERVED_PATH_H
#include <vector>
#include <ostream>

struct ConservedPath
{
  typedef int path_element;
  typedef std::vector<path_element> path_type;
  typedef path_type::iterator iterator;
  typedef path_type::const_iterator const_iterator;
  typedef path_type::size_type size_type;

  ConservedPath();
  ConservedPath(const ConservedPath& );
  ConservedPath(size_t window_size, double score, path_type path);

  //! reset our path to be empty (including setting threshold to 0)
  void clear();
  path_element& operator[](size_type index);
  void push_back(const path_element& );
  void pop_back();

  size_type size() const;
  iterator begin();
  const_iterator begin() const;
  iterator end();
  const_iterator end() const;

  friend bool operator==(const ConservedPath& a, const ConservedPath &b);
  friend bool operator!=(const ConservedPath& a, const ConservedPath &b);
  friend bool operator<(const ConservedPath& a, const ConservedPath &b);
  friend std::ostream& operator<<(std::ostream&, const ConservedPath&);

  //! return true if all elements of the path are "next to" our current path.
  /*! Next to is defined as being window index + 1
   *  that definition may not properly track reverse compliment
   *  \throws conserved_path_size_mismatch
   */
  bool nextTo(const ConservedPath& next) const;
  //! indicate which elements of the path are reversed
  std::vector<bool> reverseComplimented() const;
  //! return the list of indexes normalized (to the left)
  path_type normalizedIndexes() const;
  //! extend our current path
  //! (aka increment our window size  by growth)
  ConservedPath& extend(int growth=1);

  //! window size (really should always be positive
  size_t window_size;
  //! either number of conserved bases or average entropy
  double score;
  //! offsets into each of our sequences representing the start of our window
  path_type track_indexes;
};
#endif
